import os
import sys
import subprocess

from django.core.management.base import CommandError

from hobo.multitenant.middleware import TenantMiddleware

from .create_tenant import Command as CreateTenantCommand
from hobo.agent.common.management.commands.hobo_deploy import Command as HoboDeployCommand


class Command(CreateTenantCommand):
    help = "Create hobo tenant(s) by hostname(s)"

    def handle(self, *args, **options):
        if not args:
            raise CommandError("you must give at least one tenant hostname")
        # if - is given on the command line, get list of hostnames from stdin
        if '-' in args:
            args = list(args)
            args.remove('-')
            args.extend([x.strip() for x in sys.stdin.readlines()])

        super(Command, self).handle(*args, **options)

        # create SP keys for each tenant
        for hostname in args:
            tenant = TenantMiddleware.get_tenant_by_hostname(hostname)
            HoboDeployCommand().generate_saml_keys(tenant, prefix='sp-')
